@@ -100,7 +100,7 @@ title: {} Dental
     currentDentalProviders = set(userRef for userRef in allDentalProviders if userRef in allUserSignOnCounts)
     # Dental History (228.1) == Dental Activity
     typeSO228_1, subs = splitTypeDatas(stationNo, "228_1", reductionLabel="YR1", expectSubTypeProperty="")
-    allDentalRecordCreators = set(typeSO228_1["creator"]["byValueCount"].keys())
+    allDentalRecordCreators = set(typeSO228_1["creator"]["byValueCount"])
     if len(allDentalRecordCreators - currentDentalProviders):
         raise Exception("Expected all dental record creators to be Current Dental Providers")
     
@@ -192,17 +192,16 @@ title: {} Dental
                
 def main():
 
-    assert(sys.version_info >= (2,7))
-    
-    if len(sys.argv) < 2:
-        print "need to specify station # ex/ 442 - exiting"
-        return
-        
-    stationNo = sys.argv[1]
-    
+    assert sys.version_info >= (3, 4)
+
+    try:
+        stationNo = sys.argv[1]
+    except IndexError:
+        raise SystemExit("Usage _EXE_ STATIONNO")
+
     userSiteDir = SITE_DIR_TEMPL.format(stationNo)
     if not os.path.isdir(userSiteDir):
-        raise Exception("Expect User Site to already exist with its basic contents")
+        raise SystemExit("Expect User Site to already exist with its basic contents")
     
     webReportDental(stationNo)
     
