@@ -12,6 +12,7 @@ from fmqlutils.typer.reduceTypeUtils import singleValue
 
 """
 TODO:
+- see CVIX as user of VistAs (and even writer!) w/o VIX https://github.com/VA-Telereader/Analysis/issues/47#issuecomment-847217005 => BSE login etc. If no such entries => has VIX! ie/ a VIX VistA
 - quick tighten: remote should all have key division; locals from non local divisions (what are they?)
 - pure remotes (from all remotes)
 - pure locals
@@ -288,7 +289,9 @@ class UserClassifier:
             return False
             
         if "signed_on_froms" in userInfo:
-            raise Exception("Didn't expect proxy user {} to have visited_from".format(userRef))
+            warning = "Unexpected \"signed_on_froms\" property in SO of Proxy User"
+            self.__result["warningsByUserRef"][userRef].append(warning)
+            print("** Warning Proxy: {} for {}".format(warning, userRef))
             
         if len(set(["access_code", "verify_code"]) - set(userInfo["hasProps"])):
             raise Exception("Expected proxy user {} to have access verify".format(userRef))
