@@ -7,12 +7,21 @@ import re
 import json
 from collections import defaultdict, Counter
 from datetime import datetime
+from dateutil.relativedelta import relativedelta
 
+from fmqlutils import VISTA_DATA_BASE_DIR
 from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent, muBVC
 from fmqlutils.cacher.cacherUtils import metaOfVistA
-from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, combineSubTypes, checkDataPresent, singleValue, muBVCOfSTProp
+from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, combineSubTypes, checkDataPresent, singleValue, muBVCOfSTProp, makeTypeTSCSVByDay
 
-from ..webReportUtils import filteredResultIterator, reduce200, reduce4, reduce44, TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, roundFloat
+from fmqlreports.webReportUtils import muPlotRef, makePlots 
+from fmqlreports.webReportUtils import filteredResultIterator, reduce200, reduce4, reduce44, TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, roundFloat
+
+"""
+Tighten ups:
+- Bar chart by clinic too (along with category) AND by Appointment Type!
+- 
+"""
 
 """
 Overall: Scheduling w/VSE focus
@@ -41,7 +50,7 @@ Two VSE PDFs:
 and
 - https://www.va.gov/vdl/documents/Clinical/Scheduling/VSE_GUI_1_4_User_Guide.pdf
 """
-def reportAppointmentsVSE(stationNo, vistaName, cutDate):
+def reportAppointmentsVSE(stationNo, vistaName, cutDate, imageDir="Images"):
 
     allThere, details = checkDataPresent(stationNo, [
 
@@ -69,6 +78,15 @@ def reportAppointmentsVSE(stationNo, vistaName, cutDate):
     # IMPORTANT: 'expectNotEfficientWalked' important as "starttime" is not ien order
     allDAY90, stsDAY90 = splitTypeDatas(stationNo, "409_84", reductionLabel="DAY90", expectSubTypeProperties=["resource", "#cancel_datetime", "#noshow_datetime"], expectNotEfficientWalked=True) 
     
+    apptTypeCountDAY90 = Counter()
+    for st in stsDAY90:
+        if "appointment_type" in st: # 409_84 only
+            bvc = st["appointment_type"]["byValueCount"]
+            for v in bvc:
+                apptTypeCountDAY90[v.split(" [")[0]] += bvc[v]
+        else:
+            apptTypeCountDAY90["NONE"] += st["_total"]
+    
     # Checking for Columbus and others where VSE may be off (or never on?)
     day90Fraction = float(allDAY90["_total"])/float(_all["_total"])
     if _all["_total"] < 10000 or day90Fraction < .01:
@@ -121,6 +139,8 @@ def reportAppointmentsVSE(stationNo, vistaName, cutDate):
         PLOCMAP = None        
                 
     # ############################ MU REPORT ################################
+
+    plotData = {}
             
     mu = """VistA Scheduling Enhancements (VSE) is the package used for appointment creation and tracking. Despite the word \"Enhancements\", VSE is a new package that superceeds an older scheduling package.
     
@@ -132,39 +152,91 @@ def reportAppointmentsVSE(stationNo, vistaName, cutDate):
     # take place.
     mu += """{} records <span class='yellowIt'>{:,}</span> VSE appointments, the first in significant numbers in {}, the latest in {}. 
     
-For the 90 days before this VistA copy was cut (_{}_), the System shows <span class='yellowIt'>{}</span> appointments were scheduled for <span class='yellowIt'>{:,}</span> patients and <span class='yellowIt'>{:,}</span> \"Resources\". <span class='yellowIt'>{}</span> of these appointments were active, <span class='yellowIt'>{}</span> were formally cancelled and <span class='yellowIt'>{}</span> were \"no shows\".
-    
-The software allows a \"Resource\" to be a provider or a location but in this system, all resources with appointments from 2019 are locations - in other words, appointments are only made for locations (\"Location Appointment\"). {}.
-
 """.format(
         "__{} [{}]__".format(vistaName, stationNo),
         _all["_total"],
         firstSignificantDate,
-        lastSignificantDate,
-        
+        lastSignificantDate
+    )
+    
+    plotData["statesLatest90Days"] = {
+        "title": "Appointment States",
+        "plotName": "apptVSEStatesLatest90Days",
+        "plotMethod": "plotCategoryBH",
+        "rows": [
+            "status"
+        ],
+        "columns": [
+            "active",
+            "cancelled",
+            "noshows"
+        ],
+        "data": [
+            [
+                sum(st["_total"] for st in stsDAY90Active),
+                sum(st["_total"] for st in stsDAY90Cancelled),
+                sum(st["_total"] for st in stsDAY90NoShowed)
+            ]
+        ]
+    }
+    blurb = """For the 90 days before this VistA copy was cut (_{}_), the System shows <span class='yellowIt'>{}</span> appointments were scheduled for <span class='yellowIt'>{:,}</span> patients and <span class='yellowIt'>{:,}</span> \"Resources\". The following shows the breakdown of _active_, _formally cancelled_ and _\"no show\"_ appointments ...
+
+""".format(
         cutDate,
         reportAbsAndPercent(allDAY90["_total"], _all["_total"]),
         allDAY90["patient"]["rangeCount"],
-        allDAY90["resource"]["rangeCount"],
-        reportAbsAndPercent(
-            sum(st["_total"] for st in stsDAY90Active),
-            allDAY90["_total"]
-        ),
-        reportAbsAndPercent(
-            sum(st["_total"] for st in stsDAY90Cancelled),
-            allDAY90["_total"]
-        ),
-        reportAbsAndPercent(
-            sum(st["_total"] for st in stsDAY90NoShowed),
-            allDAY90["_total"]
-        ),
+        allDAY90["resource"]["rangeCount"]
+    )
+    mu += "{}\n\n{}\n\n".format(
+        blurb,
+        muPlotRef(plotData["statesLatest90Days"], imageDir)
+    )
+    
+    apptTypeCountDAY90Cut = Counter()
+    for apptType in apptTypeCountDAY90:
+        if apptTypeCountDAY90[apptType]/allDAY90["_total"] < .2:
+            apptTypeCountDAY90Cut["OTHER"] += apptTypeCountDAY90[apptType]
+            continue
+        apptTypeCountDAY90Cut[apptType] = apptTypeCountDAY90[apptType]
+    apptTypesSC = sorted(list(apptTypeCountDAY90Cut), key=lambda x: apptTypeCountDAY90Cut[x], reverse=True)
+    plotData["typesLatest90Days"] = {
+        "title": "Appointment Types",
+        "plotName": "apptVSETypesLatest90Days",
+        "plotMethod": "plotCategoryBH",
+        "rows": [
+            "type"
+        ],
+        "columns": apptTypesSC,
+        "data": [
+            [apptTypeCountDAY90Cut[apptT] for apptT in apptTypesSC]
+        ]
+    }
+    blurb = """and by appointment type ...
+
+"""
+    mu += "{}\n\n{}\n\n".format(
+        blurb,
+        muPlotRef(plotData["typesLatest90Days"], imageDir)
+    )
+    
+    mu += """The software allows a \"Resource\" to be a provider or a location but in this system, all resources with appointments from 2019 are locations - in other words, appointments are only made for locations (\"Location Appointment\"). {}.
+
+""".format(
         
         muProviderTotal # very unlikely: say in Columbus as moved on from VSE
     )
-            
-    mu += muByInstitutions(allDAY90, stsDAY90, plocMap=PLOCMAP)
+         
+    imu, institsGT1Percent = muByInstitutions("DAY90", allDAY90, stsDAY90, plocMap=PLOCMAP)     
+    mu += imu # calc above
     
-    mu += muAboutWorkLocation() 
+    # ####################### Time Series ################## (merge)
+            
+    # REM: want more on medians + max + min per weekday
+    tsPlotData, tsmu = muTimeSeries(stationNo, cutDate, firstSignificantDate, plotPrefix="apptVSE", institutionsToShow=institsGT1Percent, imageDir=imageDir)
+    mu += tsmu
+    plotData.update(tsPlotData)
+    
+    # ################### STOP CODE #########################
     
     """
     TODO: markup or check "length of appt" and see date appt made vs
@@ -174,8 +246,13 @@ The software allows a \"Resource\" to be a provider or a location but in this sy
     """
     propsPresenceToCount=["checkin", "checkout", "noshow", "consult_link", "provider", "cancel_datetime"]
     mu += muByStopCodes(stationNo, stsDAY90, plocMap=PLOCMAP, propsPresenceToCount=propsPresenceToCount)
-                    
+                        
     # #################### FINAL WRITE OUT ###########################
+
+    plotDir = f'{VISTA_DATA_BASE_DIR}{stationNo}/TmpWorking/'
+    print(f'Serializing vizData to {plotDir}')
+    json.dump(plotData, open(f'{plotDir}plotDataApptVSE.json', "w"), indent=4)
+
     userSiteDir = SITE_DIR_TEMPL.format(stationNo)
     print("Serializing VSE Appointment Report to {}".format(userSiteDir))
     if not os.path.isdir(userSiteDir):
@@ -207,6 +284,9 @@ def reportAppointmentsLegacy44(stationNo, vistaName, cutDate):
 
     institInfosByIEN = reduce4(stationNo)
     hlInfosByIEN = reduce44(stationNo)
+    
+    institInfosByIEN = reduce4(stationNo)
+    hlInfosByIEN = reduce44(stationNo, useRF=False)
 
     LOCN_PROP = "appointment_container_"
 
@@ -268,7 +348,8 @@ For the 90 days before this VistA copy was cut (_{}_), the System shows <span cl
         )
     )
             
-    mu += muByInstitutions(allDAY90, stsDAY90, plocMap=PLOCMAP)
+    imu, institsGT1Percent = muByInstitutions("DAY90", allDAY90, stsDAY90, plocMap=PLOCMAP)
+    mu += imu
     
     mu += muAboutWorkLocation() 
     
@@ -290,30 +371,194 @@ For the 90 days before this VistA copy was cut (_{}_), the System shows <span cl
 
 # ################################# Common MU's/ HL Enhance ###################
 
-"""
-Focus is [1] per institution and [2] stop codes as [3] work locations are combination concepts. Need to report on both [A] VPE and [B] Legacy 44.003 (and maybe per patient too)
-"""
-def muAboutWorkLocation(): # background blurb shared
+def muTimeSeries(stationNo, cutDate, firstSignificantDate, plotPrefix, institutionsToShow=None, imageDir="Images"):
+
+    plotData = {}
     
-    mu = "In VistA, location (\"Work Location\") represents the combination of [i] a type of work in [ii] a specific institution performed by [iii] a particular provider, group of providers or class of provider. Appointments and Visits are organized around these Work Locations.\n\n"
+    noMonthsBack = 48
+            
+    mu = ""
     
-    mu += "The work type of each Work Location is formally specified with a VA-custom \"stop code number\", the key designator for VA's _Decision Support System_ (DSS) ...\n\n"
+    print(f'Making CSV for TS - all data')
+    class Splitter:
     
-    # "DSS calculates the actual cost to provide patientcare services"
-    mu += "> VHA collects workload data that supports the continuity of patient care, resource allocation, performance measurement, quality management, and third-party collections. Decision Support System (DSS) Identifiers assist VA medical centers in defining workload, which is critical for costing purposes. DSS Identifiers are used to identify workload for all outpatient encounters, inpatient appointments in outpatient clinics, and inpatient billable professional services. They also serve as guides to select DSS outpatient department structures.\n\n"
+        def __init__(self, stationNo, institutionsToShow):
+            self.__stationNo = stationNo
+            self.__institutionsToShow = institutionsToShow # None = ALL     
+            self.__resourceInfosByIEN = reduce409_831(stationNo)
+            
+            self.__institutionRefByHLIEN = {}
+            self.__institutionSRefByRef = {}
+            hlInfosByIEN = reduce44(stationNo, useRF=False)
+            institInfosByIEN = reduce4(stationNo)
+            for hlIEN in hlInfosByIEN:
+                hlInfo = hlInfosByIEN[hlIEN]
+                if "institution" not in hlInfo:
+                    continue
+                institIEN = re.search(r'([\d\.]+)\]$', hlInfo["institution"]).group(1)
+                institInfo = institInfosByIEN[institIEN]                    
+                if "station_number" not in institInfo:
+                    continue
+                institutionRef = "{} [{}]".format(institInfo["label"], institIEN)            
+                self.__institutionRefByHLIEN[hlIEN] = institutionRef  
+                self.__institutionSRefByRef[institutionRef] = "{} [{}]".format(institInfo["label"], institInfo["station_number"]) 
+                
+            self.__suppressed = Counter()
+            self.__suppressedDays = Counter()
+            self.__acceptedDays = Counter()
+            
+        def split(self, resource):
+            def recordSuppressed(resource, reason):
+                self.__suppressed[reason] += 1
+                if "starttime" in resource:
+                    startDay = resource["starttime"]["value"].split("T")[0]
+                    self.__suppressedDays[startDay] += 1
+                else:
+                    self.__suppressedDays["NONE"] += 1
+                return ""
+            if "starttime" not in resource: # => CSV maker won't need to!
+                return recordSuppressed(resource, "NO START TIME")
+            if "resource" not in resource:
+                return recordSuppressed(resource, "NO RESOURCE")
+            
+            resourceInfo = self.__resourceInfosByIEN[resource["resource"]["id"].split("-")[1]]
+            if resourceInfo["source_resource_class"] != "LOCATION":
+                print(f'** Warning: Expected all resources with appointments to be LOCATION - skipping {resourceInfo["source_resource_class"]}')
+                return recordSuppressed(resource, "NOT LOC RESOURCE")
+                
+            # Could ZZ nix
+            # ... TODO: may boost 
+            hlIEN = re.search(r'([\d\.]+)\]$', resourceInfo["hospital_location"]).group(1)
+            if hlIEN not in self.__institutionRefByHLIEN:
+                return "UNKNOWN" # instit not set (most are ZZ...)
+                
+            institutionRef = self.__institutionRefByHLIEN[hlIEN]
+            if institutionRef not in self.__institutionsToShow:
+                return "" # suppress not surprising so not noting reason
+                
+            return self.__institutionSRefByRef[institutionRef]
+            
+        def suppressed(self):
+            return self.__suppressed
+
+    splr = Splitter(stationNo, institutionsToShow)
+    # Make full CSV - no cutting size
+    createdByDayCSV = makeTypeTSCSVByDay(stationNo, "409_84", "starttime", splitter=splr)
+    colNameById = dict((colId, colId) for colId in createdByDayCSV[0].split(",")[1:])
+    print(f"CSV creation - {splr.suppressed()} - {len(createdByDayCSV) - 1}")
     
-    mu += "This approach downplays physical location as one physical location may host many Work Locations. Even when specified in the system, physical location is a freeform text string that varies greatly in form and quality - it has been somewhat normalized in the tables below.\n\n"
+    mu = "## Appointments over Time\n\n"
     
-    mu += "The use of Work Locations for appointments makes _stop code_ the best mechanism for describing and typing appointments.\n\n"
+    mu += "_Note_: the following excludes clinics with less than 1% of the appointments. It also shows appointments where the institution isn't known (\"UNKNOWN\") - VistA looses institution designations if hospital locations are retired (\"ZZed\").\n\n"
     
-    return mu
+    # Three months back - NOT DOING FUTURE ie/ there may be futures but ignoring (for now)
+    cutDayDT = datetime.strptime(cutDate, "%Y-%m-%d")
+    cutDayBeforeDT = cutDayDT - relativedelta(days=1) 
+    cutDayBefore = datetime.strftime(cutDayBeforeDT, "%Y-%m-%d")
+    cutDayBeforeDisp = re.sub(r'\-', '/', cutDayBefore)
+    threeMonthsBackDayDT = cutDayDT - relativedelta(months=3)
+    threeMonthsBackDay = datetime.strftime(threeMonthsBackDayDT, "%Y-%m-%d")
+    plotData["tsDailies"] = {
+        "title": f"Appointments by Day for Latest Three Months (end {cutDayBeforeDisp})",
+        "plotName": f'{plotPrefix}',
+        "plotMethod": "plotDailies",
+        "dfcsv": createdByDayCSV,
+        "kargs": {
+            "colNameById": colNameById,
+            "start": threeMonthsBackDay,
+            "end": cutDayBefore
+        }
+    }
+    blurb = f'Daily Addition - from {threeMonthsBackDay} to {cutDayBefore} - shows the expected regular weekday levels with dips at weekends and holidays. The legend gives the minimum, median and maximum number of transactions per day. The counts for smaller clinics (<10% of appointments) are grouped together as their totals are so small ...'
+    mu += "{}\n\n{}\n\n".format(
+        blurb, 
+        muPlotRef(
+            plotData["tsDailies"],
+            imageDir
+        )
+    )
+       
+    """     
+    # No ts365RollingMean unless do CSV for all years
+    firstMonth = re.sub(r'\-\d+$', '', createdByDayCSV[1].split(",")[0])
+    lastMonth = re.sub(r'\-\d+$', '', createdByDayCSV[-1].split(",")[0])
+    plotData["ts365RollingMean"] = {
+        "title": "Trends in Appointments (365 day rolling)",
+        "plotName": f'{plotPrefix}',
+        "plotMethod": "plot365RollingMean",
+        "dfcsv": createdByDayCSV,
+        "kargs": {
+            "colNameById": colNameById,
+            "start": firstMonth, 
+            "end": lastMonth
+        }
+    }
+    blurb = "Here are the yearly trends using a __\"365 day rolling mean\"__ ..."
+    mu += "{}\n\n{}\n\n".format(
+        blurb,
+        muPlotRef(
+            plotData["ts365RollingMean"],
+            imageDir
+        )
+    )
+    """
+    
+    # TODO: may change to "end" and "timeBack" ala utility => easier to QA inside
+    # graph and no duplication logic
+    cutDayMonthBeforeDT = cutDayDT - relativedelta(months=1)
+    cutMonthBefore = datetime.strftime(cutDayMonthBeforeDT, "%Y-%m")
+    cutDay13MonthsBeforeDT = cutDayDT - relativedelta(months=13)
+    cutMonthBeforeYearBack = datetime.strftime(cutDay13MonthsBeforeDT, "%Y-%m")
+    plotData["tsMonthlyResamples"] = {
+        "title": "Appointments for the last year - Resampled Monthly",
+        "plotName": f'{plotPrefix}',
+        "plotMethod": "plotMonthlyResamples",
+        "dfcsv": createdByDayCSV,
+        "kargs": {
+            "colNameById": colNameById,
+            "start": cutMonthBeforeYearBack,
+            "end": cutMonthBefore # want full months
+        }
+    }
+    # TODO: median + weekday/ weekend on all three -- median per weekday/ max/ min?
+    blurb = f'Resample by month from {cutMonthBeforeYearBack} to {cutMonthBefore}. Note how \"UNKNOWNs\" go down with time as ZZing of locations goes up over time.'
+    mu += "{}\n\n{}\n\n".format(
+        blurb,
+        muPlotRef(
+            plotData["tsMonthlyResamples"],
+            imageDir
+        )
+    )
+    
+    plotData["tsTotalsPerYear"] = {
+        "title": "Appointments ({}-{})".format(re.sub(r'\-', '/', firstSignificantDate), re.sub(r'\-', '/', cutMonthBefore)),
+        "plotName": f'{plotPrefix}',
+        "plotMethod": "plotTotalsPerYear",
+        "dfcsv": createdByDayCSV,
+        "kargs": {
+            "colNameById": colNameById,
+            "start": firstSignificantDate,
+            "end": cutMonthBefore,
+            "snosOnly": False
+        }
+    }
+    blurb = "Finally, a simple __side by side set of totals__ ..."
+    mu += "{}\n\n{}\n\n".format(
+        blurb,
+        muPlotRef(
+            plotData["tsTotalsPerYear"],
+            imageDir
+        )
+    )
+    
+    return plotData, mu
     
 """
 By Institution summary 
 
 Expects: _institution, _stop_code_number added to st's
 """
-def muByInstitutions(_all, sts, plocMap=None): # TODO: map ploc ala sc mu below
+def muByInstitutions(label, _all, sts, plocMap=None): # TODO: map ploc ala sc mu below
 
     _allTotal = sum(st["_total"] for st in sts) # have _all too for patient range total but TODO, will move off that.
     stsByInstitution = defaultdict(list)
@@ -338,8 +583,13 @@ def muByInstitutions(_all, sts, plocMap=None): # TODO: map ploc ala sc mu below
         if "appointment_type" in st: # 409_84 only
             bvc = st["appointment_type"]["byValueCount"]
             for v in bvc:
-                apptTypeCountByInstitution[instit][v] += bvc[v] 
-                
+                apptTypeCountByInstitution[instit][v] += bvc[v]
+    # REM: as go back further, more and more have ZZ'ed locations w/o instit set and
+    # so can't gather by institution
+    print(f'** Warning "{label}" STs: {sum(st["_total"] for st in stsNoInstitution)} out of {_allTotal} entries have no specified Institution - very few as few ZZ locations w/o institution in last 90 days')
+
+    institsGT1Percent = set(instit for instit in apptCountByInstitution if apptCountByInstitution[instit]/_allTotal > 0.01) 
+
     def weekdayWeekendCounts(st, wdweCounts):
         if not ("_createDateProp" in st and st["_createDateProp"] in st):
             return wdweCounts
@@ -355,17 +605,20 @@ def muByInstitutions(_all, sts, plocMap=None): # TODO: map ploc ala sc mu below
         cols.append(":Appointment Types")
     tbl = MarkdownTable(cols)
     for instit in sorted(apptCountByInstitution, key=lambda x: apptCountByInstitution[x], reverse=True):
-        name = re.sub(r' +$', '', instit.split(" [")[0])
-        nameMU = "__{}__ [{}]".format(name, st["_station_number"]) if "_station_number" in st else "__{}__".format(name)
         byStopCodeCount = Counter()
         hlocPrefixes = Counter()
         wdweCounts = Counter()
+        stationNumber = ""
         for st in stsByInstitution[instit]:
             if "_stop_code_number" not in st:
                 continue
+            if "_station_number" in st:
+                stationNumber = st["_station_number"]
             byStopCodeCount[st["_stop_code_number"]] += 1
             hlocPrefixes[st["_prefix"] if "_prefix" in st else "NO PREFIX"] += 1
             wdweCounts = weekdayWeekendCounts(st, wdweCounts)
+        name = re.sub(r' +$', '', instit.split(" [")[0])
+        nameMU = "__{}__ [{}]".format(name, stationNumber) if instit in institsGT1Percent else "{} [{}]".format(name, stationNumber)
         weekendMU = reportPercent(wdweCounts["WE"], apptCountByInstitution[instit]) if wdweCounts["WE"] != 0 else ""
         row = [
             nameMU,
@@ -398,6 +651,24 @@ def muByInstitutions(_all, sts, plocMap=None): # TODO: map ploc ala sc mu below
             ) 
         )
     
+    return mu, institsGT1Percent
+    
+"""
+Focus is [1] per institution and [2] stop codes as [3] work locations are combination concepts. Need to report on both [A] VPE and [B] Legacy 44.003 (and maybe per patient too)
+"""
+def muAboutWorkLocation(): # background blurb shared
+    
+    mu = "In VistA, location (\"Work Location\") represents the combination of [i] a type of work in [ii] a specific institution performed by [iii] a particular provider, group of providers or class of provider. Appointments and Visits are organized around these Work Locations.\n\n"
+    
+    mu += "The work type of each Work Location is formally specified with a VA-custom \"stop code number\", the key designator for VA's _Decision Support System_ (DSS) ...\n\n"
+    
+    # "DSS calculates the actual cost to provide patientcare services"
+    mu += "> VHA collects workload data that supports the continuity of patient care, resource allocation, performance measurement, quality management, and third-party collections. Decision Support System (DSS) Identifiers assist VA medical centers in defining workload, which is critical for costing purposes. DSS Identifiers are used to identify workload for all outpatient encounters, inpatient appointments in outpatient clinics, and inpatient billable professional services. They also serve as guides to select DSS outpatient department structures.\n\n"
+    
+    mu += "This approach downplays physical location as one physical location may host many Work Locations. Even when specified in the system, physical location is a freeform text string that varies greatly in form and quality - it has been somewhat normalized in the tables below.\n\n"
+    
+    mu += "The use of Work Locations for appointments makes _stop code_ the best mechanism for describing and typing appointments.\n\n"
+    
     return mu
     
 """
@@ -553,6 +824,9 @@ def muByStopCodes(stationNo, sts, plocMap=None, propsPresenceToCount=[]):
 
     mu = "## By Stop Code\n\n"
     # May add: The range of states transitioned by appointments from checkin to checkout seems to vary with work type.
+    
+    mu += muAboutWorkLocation() # the blurb
+    
     mu += """The system holds <span class='yellowIt'>{}</span> in-person, clinical appointments. There are also <span class='yellowIt'>{}</span> _TELEPHONE_, <span class='yellowIt'>{}</span> _COMMUNITY CARE_, <span class='yellowIt'>{}</span> _in home care_, <span class='yellowIt'>{}</span> _Telehealth_ and <span class='yellowIt'>{}</span> _administrative appointments_.
     
 The tables below break down appointments by institution. _Location_ counts the root or base of location names as the number of individual locations in larger institutions get unmanageable for a table and _Physical Location_ shows the free text names given for buildings and rooms. _Props_ count how many appointments have defining properties such as _"cancel datetime"_ or _checked out_. 
@@ -629,6 +903,7 @@ def enhanceHLocSTsByLOC(institInfosByIEN, hlInfosByIEN, sts, locationProp="_hosp
         try:
             hlInfo = hlInfosByIEN[hlIEN]
         except:
+            print("Couldn't find {} for {} - probably hl red is incomplete".format(hlIEN, locationProp))
             raise
         addHLPropsToApptST(st, hlInfo)
         if "institution" not in hlInfo:
@@ -708,6 +983,12 @@ def main():
         stationNo = sys.argv[1]
     except IndexError:
         raise SystemExit("Usage _EXE_ STATIONNO")
+    
+    if len(sys.argv) > 2:
+        if sys.argv[2] == "PLOT":
+            makePlots(stationNo, "ApptVSE")
+            return
+        raise Exception("Only extra argument allowed is 'PLOT'")
 
     ensureWebReportLocations(stationNo)
     
